#! /usr/bin/env python
# -*- coding: utf-8 -*-


import sys
from optparse import OptionParser
from Model.snow_pro import SnowpitModelNetcdf

#                        Program snow_pro
#                        ################

#  objective :
#-------------#

#    After a surfex-crocus or a crocus-v24 simulation creation of a netcdf file containing
#    snowpack-relevant variables produced during the simulation

#  Method :
#----------#
#    creation of two objects in the program , an object related to the output file and an other related to the input file(s).
#    The object input file will  deliver data to the object output file  Presently, we consider different type of input file :
#        surfexV6 : use of the file  ISBA_PROGNOSTIC.OUT.nc . No use of ISBA_DIAGNOSTICS.OUT.nc. Only netcdf surfex file is allowed
#            These files contains a time variable
#        surfexV61 : Same file than surfexV6. This file contains spatial coordinates (one dimension for latitude and one dimension for longitude)
#        surfexV5 : Same file than surfexV6 but the file does not contain time variable
#        crocus (v24) : use of the binary file output of the crocus simulation. the file name must be PRO
#        crocusSSA : same as crocus but the binary file contains SSA variables (LGGE crocus simulation). the file name must be PROSSA
#        crocusSCM : same as crocus but the binary file is in big endian and the date increasing is controlled ( Safran-Crocus simulation). the file name must be PROSCM
#    The program reads the active directory and determines (with their name) which input files are present for the determination of the type of simulation.

#    the name of the output netcdf file is PRO.nc

#  Arguments :
#------------#
#    no argument is required . If one argument is set it must be a string and this string will be add initialise the global attribute 'SIMULATIONTYPE'


#  Author  :
#----------#
#        Jean-Marie Willemet     mail :jean-marie.willemet@meteo.fr
#        Samuel Morin         mail : samuel.morin@meteo.fr

# Version   :
# 2010-09-28 : pre-beta release for testing purpose

#Modifications :
#--------------#
#    2010-09-28 : JM Willemet - creation
#       2010-09-30 :             - bug correction and add a simplified grain type calculation
#       2010-10-26 :             - add mepra variables calculation and PROSSA ( PRO file with SSA - LGGE formulation)
#       2010-10-29 :             - add possibility to treat surfex files with spatial information
#       2010-11-04 :             - add possibility to treat a PRO file issued of the research SCM name of the file PROSCM
#       2010-11-16 :             - bug correction in mepra variables . crocus file is renamed file PRO is searched in place of PRO01. No choice in the name of output file (PRO.nc obligatory)
#                                  LGGE SSAs are renamed . optimisation in the reading of the crocus file
#       2011-02-28 :             - date format is modified in the attribute of time :  hour-min-second is replaced by hour:min:second
#                                  the format hour:min:second is allowed in the units attribute of time in the surfex input file
#                                  shear units is put in dPa in place of DaN/dm2 (bug correction)
#       2011-04-06 :             - with surfex V5 namelist reading is not correct
#       2011-04-18 :             - modification on the dimensions of the output file
#                                    - suppress dimension concerning slope, aspect and and altitude
#                                    - rename snow_layer and tile
#                                    - 2 types of geographical location :
#                                         - input file is on a rectangular grid,  two dimensions : lon and lat
#                                         - input file is on a non regular grid  one dimension : location
#                                    - three new variables which depends of the geographical location : altitude - aspect - slope
#      2011-05-03 :              - add possibility to read information on PRO.nc file
#      2011-05-30 :              - possibility to add spatial information (altitude-aspect-slope) in case of SCM file (using of the SCMtools class)
#                                - add cdtime module (a part of the cdat software) for treatment on the dates of the type : XXXX since DATE
#                                - addition is surcharged Presently addition of PRO.nc object is following the dimension location
#      2011-08-03 :              - litle modifications in the long name and in the units
#                                - SNOWTYPE is suppressed  in the output file
#                                - 3 soil parameters of the top layer are saved in the output file
#                                - new variable : SSA calculation from MEPRA cristal and density
#                                - Supression of the use of ISBA_DIAGNOSTICS.OUT.nc file depth and swe are calculated from SNOWDZ and SNOWRO
#      2011-08-25 :              - bugue correction in get_msnst
#      2011-08-26 : S. Morin     - add upscale_tab and upscale_tab_time (will replace radslope)
#      2011-09-14 : JM Willemet  - Scientific.IO is replaced by NetCDF4-python
#      2011-10-13 : JM Willemet  - modification in the SSA_TYP  calculation
#      2012-02-28 : JM Willemet  - reading of the MEPRA file (binary file created by fortran code)  conversion of one location (given by info_spatial) in netcdf file
#                                  The name of the binary MEPRA file must be MEP
#      2012-04-18 : M Lafaysse   - add a method to associate areas to simulation points in netcdf files.
#      2012-04-24 : JM Willemet  - refactoring snow_pro is created in the script/model directory whithout class 
#      2012-06-29 : JM Willemet  - add the possibility to define the run name (in oper dawn, morning, afternoon or evening) and run time
#      2012-12-21 : JM Willemet  - modification in the use of arguments ( use of the module optparse)  
#                                  add metamo argument

if __name__ == "__main__":
    
    
    usage = "usage: %prog -f outputFile -m metamo -s simulationType -r runName -a analysisTime"
    parser = OptionParser(usage)
    
    #parser.add_option("-v", "--verbose",
    #                  action="store_true", dest="verbose")

    parser.add_option("-f", "--outputFile",
                      action="store", type="string", dest="outputFile", default="PRO.nc",
                      help="name of the output file (with path) - default: PRO.nc")

    parser.add_option("-m", "--metamo",
                      action="store", type="string", dest="metamo", default="B92",
                      help="metamorphisme calculation presently B92 or C13 - default: B92")
    
    parser.add_option("-s", "--simulationType",
                      action="store", type="string", dest="simulationType", default="PRA",
                      help="content of the global attribute SIMULATIONTYPE - default: PRA")   
     
    parser.add_option("-r", "--runName",
                      action="store", type="string", dest="runName", default=None,
                      help="supplementary information of the simulation - " +
                           "for the operation value are S2M_1 S2M_2 S2M_3 S2M_4 for " +
                           "dawn morning afternoon or evening simulation - default: None")    
        
    parser.add_option("-a", "--analysisTime",
                      action="store", type="string", dest="analysisTime", default=None,
                      help="supplementary information of the simulation - " +
                           "for the operation date in isoformat and correspond to the end of the analysis period - default: None")           
    
    (options, args) = parser.parse_args(sys.argv)
   
    NCTOT=SnowpitModelNetcdf(filename=options.outputFile,simulationType=options.simulationType)

    # creation of the output file
    NCTOT.createNewFile(simulationType=options.simulationType, 
                        runName=options.runName, 
                        runTime=options.analysisTime, 
                        metamo = options.metamo)

    # that's the end
    NCTOT.ficnetcdf.close()
